@@ -271,6 +271,7 @@ from guiqwt.events import (
     QtDragHandler,
     ZoomRectHandler,
     RectangularSelectionHandler,
+    PointSelectionHandler,
     ClickHandler,
 )
 from guiqwt.shapes import (
@@ -887,12 +888,15 @@ class RectangularActionTool(InteractiveTool):
         self.last_final_shape = weakref.ref(shape)
         return shape
 
+    def get_selection_handler(self, filter, start_state):
+        return RectangularSelectionHandler(
+            filter, Qt.LeftButton, start_state=start_state
+        )
+
     def setup_filter(self, baseplot):
         filter = baseplot.filter
         start_state = filter.new_state()
-        handler = RectangularSelectionHandler(
-            filter, Qt.LeftButton, start_state=start_state
-        )
+        handler = self.get_selection_handler(filter, start_state)
         shape, h0, h1 = self.get_shape()
         handler.set_shape(
             shape, h0, h1, self.setup_shape, avoid_null_shape=self.AVOID_NULL_SHAPE
@@ -991,6 +995,9 @@ class PointTool(RectangularShapeTool):
         self.set_shape_style(shape)
         return shape, 0, 0
 
+    def get_selection_handler(self, filter, start_state):
+        return PointSelectionHandler(filter, Qt.LeftButton, start_state=start_state)
+
 
 class SegmentTool(RectangularShapeTool):
     TITLE = _("Segment")
@@ -2146,14 +2153,15 @@ class HelpTool(CommandTool):
             plot,
             _("Help"),
             _(
-                """Keyboard/mouse shortcuts:
-  - single left-click: item (curve, image, ...) selection
-  - single right-click: context-menu relative to selected item
-  - shift: on-active-curve (or image) cursor
-  - alt: free cursor
-  - left-click + mouse move: move item (when available)
-  - middle-click + mouse move: pan
-  - right-click + mouse move: zoom"""
+                """<b>Keyboard/mouse shortcuts:</b><br><br>
+  - <u>single left-click</u>: item (curve, image, ...) selection<br>
+  - <u>single right-click</u>: context-menu relative to selected item<br>
+  - <u>shift</u>: on-active-curve (or image) cursor (+ <u>control</u> to maintain cursor visible)<br>
+  - <u>shift + control</u>: on-active-curve cursor (+ <u>control</u> to maintain cursor visible)<br>
+  - <u>alt</u>: free cursor<br>
+  - <u>left-click + mouse move</u>: move item (when available)<br>
+  - <u>middle-click + mouse move</u>: pan<br>
+  - <u>right-click + mouse move</u>: zoom"""
             ),
         )
 
